from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String

Rsat_Supported_Organisms_V0_1_0 = CommandToolBuilder(tool="rsat_supported_organisms", base_command=["rsat", "supported-organisms"], inputs=[ToolInput(tag="in_help", input_type=Boolean(optional=True), prefix="-help", doc=InputDocumentation(doc="(must be first argument) display options")), ToolInput(tag="in_format", input_type=String(optional=True), prefix="-format", doc=InputDocumentation(doc="format\nsupported: tab,tree,html_tree,newick\ntab: tab-delimited text format, with one row per\norganism and one column per field (see option\n-return).\ntree: a textual representation of the tree, with\nhyphen-based indentation to indicate taxon depth.\nhtml_tree: same as tree, but wiht HTML tags (organism\nnames in italics, taxon names in bold).")), ToolInput(tag="in_return", input_type=String(optional=True), prefix="-return", doc=InputDocumentation(doc="fields\nsupported: ID,name,taxid,source,last_update,nb,seq_format,up_from,up_to,taxonomy,data,genome,genome_assembly,genome_version,download_date,variant_available,variant_source,path_to_variant_files,blast_available")), ToolInput(tag="in_tax_on", input_type=String(optional=True), prefix="-taxon", doc=InputDocumentation(doc="Only returns organisms belonging to a selected taxon.\nExample:\nsupported-organisms -taxon Enterobacteriaceae")), ToolInput(tag="in_group", input_type=String(optional=True), prefix="-group", doc=InputDocumentation(doc="Only returns organisms belonging to a selected\n'taxonomic' group.\nSupported groups (as defined by EnsemblGenomes):\nFungi\nProkaryotes\nBacteria\nArchaea\nProtists\nMetazoa\nPlants\nNote that some of the 'groups' correspond to a specific\ntaxon defined by its systematic name (e.g. Metazoa,\nFungi) or by its common name (Plants, Prokaryotes),\nwhilst others are defined according ot the common usage\n(e.g. Protists) but do not properly speaking correspond\nto a taxonomic group. These non-taxonomic groups are\nconverted as follows:\n- 'Protists' is converted to\n'(Eukaryota NOT (Metazoa OR Fungi)) OR EnsemblProtists'\n- 'Plants' is converted to Viridiplantae\n- 'Prokaryotes' is converted to 'Bacteria OR Archaea'\nExample:\nsupported-organisms -taxon Protists\nsupported-organisms -taxon Prokaryotes")), ToolInput(tag="in_source", input_type=String(optional=True), prefix="-source", doc=InputDocumentation(doc="Only return organisms from a user-selected source(s).\nThis argument can be used iteratively to accept\nmultiple sources.\nExample:\nsupported-organisms -source ensembl\nsupported-organisms -source ensemblgenomes\nsupported-organisms -source ensembl -source ensemblgenomes")), ToolInput(tag="in_depth", input_type=Boolean(optional=True), prefix="-depth", doc=InputDocumentation(doc="#\nDepth for exploring the taxonomic tree. When the value\ndiffers from 0, the program only returns one\n'representative' organism per taxon of the specified\ndepth.\nThis option is convenient to select a non-redundant set\nof species. Note that the biological relevance of the\nresult strongly depends on the annotation of the\ntaxonomy in the original database from whichb RSAT\ngenomes were downloaded.\nPositive value indicate that the tree should be\ntraversed from root to leaves.\nNegative values indicate that the tree should be\ntraversed from leaves to root. Beware: level 0 is the\nspecies. Level -1 this corresponds to the lowest level\nof the taxonomy.\nAlso note that the depth of the taxonomic annotations\nvary along branches, so that positive values will give\ndifferent results from negative values.")), ToolInput(tag="in_unique_species", input_type=Boolean(optional=True), prefix="-unique_species", doc=InputDocumentation(doc="Select at most one organism per species. This option\naims at avoiding to be submerged by hundreds of\nstrains sequenced for the same species\n(e.g. Escherichia coli).\nSince the current annotations do not contain any\nexplicit mention of the taxonomic depth in the\ntaxonomic classification, we use a somewhat pedestrial\ncriterion to identify species, by considering the\nfirst word of the organism name as the genus, and the\nsecond name as the species.")), ToolInput(tag="in_unique_genus", input_type=Boolean(optional=True), prefix="-unique_genus", doc=InputDocumentation(doc="Select at most one organism per genus. See option\n-unique_species for the details.")), ToolInput(tag="in_server", input_type=String(optional=True), prefix="-server", doc=InputDocumentation(doc="the list of organisms supported on a remote\nRSAT server, via the Web services interface\n(http://www.rsat.eu/web_services/RSATWS.wsdl).\nThe option -server can be combined with the option\n-taxon in order to obtain the list of organisms\nsupported on the main RSAT server, before downloading\nthem.\nEx:\nsupported-organisms -taxon Fungi -server\nAn alternative server RSAT server can be selected by\nspecifying the URL of the Web server.\nsupported-organisms -server http://embnet.ccg.unam.mx/rsa-tools\n")), ToolInput(tag="in_supported_organisms", input_type=String(), position=0, doc=InputDocumentation(doc="USAGE")), ToolInput(tag="in_jacques_dot_van_helden_dot_fr", input_type=String(), position=0, doc=InputDocumentation(doc="Management of taxonomic tree: \nRekin's Janky (Rekins.Janky@vib.be).")), ToolInput(tag="in_genomes", input_type=String(), position=0, doc=InputDocumentation(doc="OPTIONS"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Rsat_Supported_Organisms_V0_1_0().translate("wdl", allow_empty_container=True)

